@@ -13,8 +13,8 @@ import scipy
 import pandas as pd
 from scipy.sparse import issparse
 
-from .modal.vae import VAE
-from .modal.utils import EarlyStopping
+from .model.vae import VAE
+from .model.utils import EarlyStopping
 from .metrics import batch_entropy_mixing_score, silhouette
 from .logger import create_logger
 from .data_loader import load_data
